﻿// ====================================================================
//  Texy.net - XML-RPC client for Texy! formatter
//  (c) 2006 Aleš Roubíček - Creative Commons 2.5 License
// --------------------------------------------------------------------
//  version: 1.0 RC2
// ====================================================================

using System;

namespace Rarous.TexyNet.Modules
{
    /// <summary>
    /// Třída obsahující informace o konfiguraci Blokového modulu
    /// </summary>
    public class BlockModule
    {
        #region Fields
        private bool allowedPre;
        private bool allowedText;
        private bool allowedHtml;
        #endregion

        #region Constructors
        /// <summary>
        /// Konstruktor.
        /// </summary>
        public BlockModule()
        {
            allowedHtml = true;
            allowedPre = true;
            allowedText = true;
        }

        /// <summary>
        /// Konstruktor
        /// </summary>
        /// <param name="element"></param>
        public BlockModule(Configuration.BlockModuleElement element)
            : this()
        {
            ReadConfiguration(element);
        }
        #endregion

        #region Private Methods
        private void ReadConfiguration(Configuration.BlockModuleElement element)
        {
            if (element == null)
            {
                return;
            }

            allowedHtml = element.AllowedHtml;
            allowedPre = element.AllowedPre;
            allowedText = element.AllowedText;
        }
        #endregion

        #region Properties
        /// <summary>
        /// Příznak, zda-li je povoleno vkládání bloků Pre
        /// </summary>
        public bool AllowedPre
        {
            get { return allowedPre; }
            set { allowedPre = value; }
        }

        /// <summary>
        /// Příznak, zda-li je povoleno vkládání bloku, ve kterém je vypnuta Texy
        /// </summary>
        public bool AllowedText
        {
            get { return allowedText; }
            set { allowedText = value; }
        }

        /// <summary>
        /// Příznak, zda-li je povoleno vkládání bloku, ve kterém je vypnuta Texy a zpracovává se pouze HTML
        /// </summary>
        public bool AllowedHtml
        {
            get { return allowedHtml; }
            set { allowedHtml = value; }
        }
        #endregion
    }
}
