﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Rarous.TexyNet.Modules
{
    /// <summary>
    /// Třída obsahující informace o konfiguraci modulu obrázků
    /// </summary>
    public class ImageModule
    {
        #region Fields
        private string root;
        private string linkedRoot;
        private string leftClass;
        private string rightClass;
        private string defaultAlt;
        private IList<Reference> references;
        #endregion

        #region Constructors
        /// <summary>
        /// Create image module
        /// </summary>
        /// <param name="element">Element</param>
        public ImageModule(Configuration.ImageModuleElement element) 
            : this()
        {
            ReadConfiguration(element);
        }

        /// <summary>
        /// Konstruktor
        /// </summary>
        public ImageModule()
        {
            root = String.Empty;
            linkedRoot = String.Empty;
            leftClass = "left";
            rightClass = "right";
            defaultAlt = String.Empty;
            references = new List<Reference>();
        }
        #endregion

        #region Private Methods
        private void ReadConfiguration(Configuration.ImageModuleElement element)
        {
            if (element == null)
            {
                return;
            }

            root = element.Root;
            linkedRoot = element.LinkedRoot;
            leftClass = element.LeftClass;
            rightClass = element.RightClass;
            defaultAlt = element.DefaultAlt;
        } 
        #endregion

        #region Properties
        /// <summary>
        /// Vraci kolekci referencí.
        /// </summary>
        public IList<Reference> References
        {
            get { return references; }
        }
        /// <summary>
        /// Vrací nebo nastavuje relativní cestu ke složce obrázků (náhledů)
        /// </summary>
        public string Root
        {
            get { return root; }
            set { root = value; }
        }

        /// <summary>
        /// Vrací nebo nastavuje relativní cestu ke složce obrázků (detailů)
        /// </summary>
        public string LinkedRoot
        {
            get { return linkedRoot; }
            set { linkedRoot = value; }
        }

        /// <summary>
        /// Vrací nebo nastavuje třídu pro obrázek zarovnaný vlevo
        /// </summary>
        public string LeftClass
        {
            get { return leftClass; }
            set { leftClass = value; }
        }

        /// <summary>
        /// Vrací nebo nastavuje třídu pro obrázek zarovnaný vpravo
        /// </summary>
        public string RightClass
        {
            get { return rightClass; }
            set { rightClass = value; }
        }

        /// <summary>
        /// Vrací nebo nastavuje výchozí alternativní text obrázku
        /// </summary>
        public string DefaultAlt
        {
            get { return defaultAlt; }
            set { defaultAlt = value; }
        }
        #endregion
    }
}
